@@ -8,12 +8,14 @@
 #include "SDL/SDL_mixer.h"
 
 #include <QtGui>
+
+#ifdef Q_WS_MAEMO_5
 #include <QtDBus>
 #include <QtMaemo5>
 
 #include <mce/mode-names.h>
 #include <mce/dbus-names.h>
-
+#endif
 
 namespace Ui {
     class MainWindow;
@@ -25,19 +27,25 @@ public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+#ifdef Q_WS_MAEMO_5
     void setPortrait();
     void setLandscape();
+#endif
 
 public slots:
     void onBtnClick();
     void onTimeout();
     void onSliderChanged(int value);
     void onTimeSigChange(int i);
+#ifdef Q_WS_MAEMO_5
     void orientationChanged(const QString &newOrientation);
+#endif
 
 protected:
     void changeEvent(QEvent *e);
+#ifdef Q_WS_MAEMO_5
     bool event(QEvent *ev);
+#endif
 
 private:
     Ui::MainWindow *ui;
